#include "datatypes.h"
#include "constants.h"
#include "draw_objects.h"

#ifndef __ACCEL_HEADER__
  #define __ACCEL_HEADER__

  // status flags
  extern uint8_t ACCEL_status;
  extern uint8_t CALIB_status;

  // acc variables
  extern int32_t accX[], accY[], accZ[];
  extern int16_t samples[NUMAXIS];
  extern int32_t calibX, calibY, calibZ;
  extern int32_t sortedArray[], accMod[], filtSig[];

  // TFT module connections
  extern unsigned int TFT_DataPort;
  extern sbit TFT_RST;
  extern sbit TFT_RS;
  extern sbit TFT_CS;
  extern sbit TFT_RD;
  extern sbit TFT_WR;
  extern sfr sbit TFT_BLED;

  // TFT module CS
  extern sbit Mmc_Chip_Select;

  // Touch Panel module connections
  extern sbit DriveX_Left;
  extern sbit DriveX_Right;
  extern sbit DriveY_Up;
  extern sbit DriveY_Down;

  // fonts
  extern const code char Arial30x33_Regular[];
  extern const code char Arial16x18_Regular[];
  extern const code char Arial11x14_Regular[];
  extern const code char Stopmotion72x86_Regular[];
  extern const code char Stopmotion36x43_Regular[];

  // images
  extern const code char welcomeScreen[];
  extern const code char startImg[];
  extern const code char stopImg[];
  extern const code char calibWelScr[];
  
  // color arrays
  extern uint16_t rClrz[], yClrz[];
  extern uint16_t* countsColor;
  
  // screen objects
  extern char stepsCaption[];
  extern clabel_t* const stepsFig;
  
  extern char counterCaption[];
  extern label_t* const counterFig;
  
  extern uint8_t timeCaption[];
  extern label_t* const timeFig;
  
  extern clabel_t* const idleFig;
  extern clabel_t* const thrBigFig;

  extern cimage_t* const welScrFig;
  extern label_t* const wsMsgFig;

  extern image_t *local_image, *exec_image;
  extern uint16_t xCrd, yCrd;

  extern cimage_t* const startFig;
  extern cimage_t* const stopFig;

  extern cimage_t* const calibWsFig;

  // Interfaces for functions
  ///////////////////////////

  // Start using accelerometer
  void AccelStart(uint8_t*);
  // Calibrate accelerometer
  void AccelCalibrate(uint8_t*);
  // check buffer state
  bool_t CheckBuffer();

  // start/stop the pedometer
  void ToggleApp();
  
  // Initialize the MCU screen
  void InitMCU();
  // Draw the beginning screen
  void DrawAccelScr(void);

  // Touch Panel
  void InitializeTouchPanel();
  void CalibrateScreen();

  // ADC
  void Init_ADC();

  // draw and erase stuff
  inline void DrawLabel(label_t*);
  inline void EraseLabel(label_t*,uint16_t);
  inline void UpdateStepsCounter();
  inline void DrawImage(image_t*);
  inline void EraseImage(image_t*, uint16_t);
  void StartSeq();

  // time-related functions and variables
  void UpdateScreen();
  extern int32_t wtHour, wtMin, wtSec;
  extern int32_t secBuffer;
  extern uint32_t timerTick;
  
  // bouncing of the button on the screen is taken care with this variable
  extern int32_t bncVal;
  
  // variables used in main
  /////////////////////////
  
  extern int32_t tmp, currCand, currSam, currRef;
  extern int32_t vpp, vppChange, prethVpp, win;

  // counters
  extern uint8_t i,j,k;
  
  // flags
  extern bool_t begin,
                initStep,
                currBuffer,
                prevCross,
                negCross,
                posCross,
                cond1,
                cond2,
                cond3,
                walkingMode,
                stepFlag,
                walkFlag,
                updateTime,
                calcSteps,
                startPedometer;

  // threshold parameters
  extern int32_t noiseThr, dynThr, rangeThr, calibRangeThr, currThr, tmpThr;
  
  // variables related to steps
  extern int32_t step, validStep, walkStep, consecSteps, consecValSteps;

  // calibration variables
  extern int32_t calibMin, calibMax;
  extern int32_t stillVpp;
  extern int32_t calibMod[];
  extern int32_t cAccX[], cAccY[], cAccZ[];
  extern uint8_t intSources;

#endif