#include "accel_driver.h"
#include "accel_header.h"
#include "constants.h"
#include "datatypes.h"
#include "dsp.h"

/**************************************************************************************************
* Function ACCEL_Start()
* -------------------------------------------------------------------------------------------------
* Overview: Function configures the acceloremeter module
* Input: Nothing
* Output: test status: 0 - skiped; 1 - pass; 2 - fail
**************************************************************************************************/
void AccelStart(uint8_t* test) {

// Reset the error flag
  *test = 0;

  // configure ADXL345 accelerometer

  if (ADXL345_Init() == 0)
  {
     *test = 1;
  }
  else
  {
     TFT_Fill_Screen(CL_BG);
     TFT_Set_Font(TFT_defaultFont, CL_RED, FO_HORIZONTAL);
     TFT_Write_Text("Error!", 75, 120);
     Delay_ms(500);
     *test = 2;
  }
}

/**************************************************************************************************
* Function AccelCalibrate()
* -------------------------------------------------------------------------------------------------
* Overview: Save the average sample values for X, Y and Z-axis while standing still and saving them onto SD card
* Input: Nothing
* Output: test flag
**************************************************************************************************/
void AccelCalibrate(uint8_t* test)
{
  
  uint16_t i = 0;
  uint8_t samplesBuffer[12];
  
  // resetting the error flag
  *test = 0;

  DrawLabel(wsMsgFig);

  // if bus is busy, wait for SDA to go high before initializing i2C moduo
  GPIO_Digital_Output(&GPIOB_BASE, _GPIO_PINMASK_6);
  GPIO_Digital_Input(&GPIOB_BASE, _GPIO_PINMASK_7);

  GPIOB_ODR.B6 = 1;
  while (GPIOB_IDR.B7 == 0)
  {
    GPIOB_ODR.B6 = 0;
    Delay_us(10);
    GPIOB_ODR.B6 = 1;
    Delay_us(10);
  }
  
  // initialize soft-I2C communication
  Soft_I2C_Init();
  
  // Initialize I2C communication
  // I2C1_Init_Advanced(100000, &_GPIO_MODULE_I2C1_PB67);
  
  if (ADXL345_CalibInit() == 0)
  {
    *test = 1;
    
    // acquisition
    for (i = 0; i < CALIBSAM; i++)
    {
        AccelReadAll(samples);
        calibX += (int32_t)(samples[0]);
        calibY += (int32_t)(samples[1]);
        calibZ += (int32_t)(samples[2]);
        
        cAccX[i] = (int32_t)samples[0];
        cAccY[i] = (int32_t)samples[1];
        cAccZ[i] = (int32_t)samples[2];

        Delay_ms(SAMPERIOD);
    }
    
    // averaging
    calibX /= CALIBSAM;
    calibY /= CALIBSAM;
    calibZ /= CALIBSAM;
    
    for (i = 0; i < CALIBSAM; i++)
    {
      cAccX[i] = cAccX[i] - calibX;
      cAccY[i] = cAccY[i] - calibY;
      cAccZ[i] = cAccZ[i] - calibZ;
      calibMod[i] = ( cAccX[i]*cAccX[i] +
                      cAccY[i]*cAccY[i] +
                      cAccZ[i]*cAccZ[i] );
    }
    
    FindExtr(calibMod, CALIBSAM, &calibMin, &calibMax);
    stillVpp = calibMax-calibMin;
    currThr = STILLVPPMULT*stillVpp;
    prethVpp = (1/THPER)*currThr;
  }
  else
  {
    *test = 2;
    TFT_Fill_Screen(CL_BG);
    TFT_Set_Font(TFT_defaultFont, CL_RED, FO_HORIZONTAL);
    TFT_Write_Text("Error!", 100, 120);
    Delay_ms(500);
  }
}
bool_t CheckBuffer()
{
  intSources = ADXL345_Read(_INT_SOURCE);
  if ((intSources & 0x02) == 0x02) return 1;
  else return 0;
}