#include "draw_objects.h"
#include "accel_header.h"

// Global Variables

// status flags
uint8_t ACCEL_status;
uint8_t CALIB_status;

// samples from accelerometer
int16_t samples[NUMAXIS] = {0,0,0};

// axis sample arrays
int32_t accX[NUMSAM], accY[NUMSAM], accZ[NUMSAM];
int32_t accMod[NUMSAM], filtSig[NUMSAM], sortedArray[NUMSAM];

// calibration
int32_t calibX = 0, calibY = 0, calibZ = 0;
int32_t calibMin = 0, calibMax = 0, calibRangeThr  = 0;
int32_t calibs[CALIBMAX];
int32_t vppChange = 0;
int32_t stillVpp = 0;
int32_t calibMod[CALIBSAM];
int32_t cAccX[CALIBSAM], cAccY[CALIBSAM], cAccZ[CALIBSAM];

// screen objects
uint16_t xCrd, yCrd;
image_t *local_image, *exec_image;

char stepsCaption[] = "steps";
clabel_t stepsLbl =
{
     53                    , //   stepsLbl.Left
     20                    , //   stepsLbl.Top
     91                    , //   stepsLbl.Width
     46                    , //   stepsLbl.Height
     stepsCaption          , //   stepsLbl.Caption
     Stopmotion36x43_Regular    , //   stepsLbl.FontName
     CL_LIGHT              , //   stepsLbl.Font_Color
};
clabel_t* const stepsFig = &stepsLbl;

uint8_t timeCaption[] = "00:00:00";
label_t timeLbl =
{
     67                    , //   timeLbl.Left
     152                   , //   timeLbl.Top
     75                    , //   timeLbl.Width
     36                    , //   timeLbl.Height
     timeCaption           , //   timeLbl.Caption
     Arial30x33_Regular    , //   timeLbl.FontName
     CL_LIGHT              , //   timeLbl.Font_Color
};
label_t* const timeFig = &timeLbl;

uint8_t counterCaption[] = "0000";
label_t counterLbl =
{
     17                    , //   counterLbl.Left
     67                    , //   counterLbl.Top
     206                   , //   counterLbl.Width
     115                   , //   counterLbl.Height
     counterCaption        , //   counterLbl.Caption
     Stopmotion72x86_Regular    , //   counterLbl.FontName
     CL_YELLOW             , //   counterLbl.Font_Color
};
label_t* const counterFig = &counterLbl;

uint8_t wsMsgCaption[] = "please stand still...";
label_t wsMsg =
{
      96                    , //   wsMsg.Left
      272                   , //   wsMsg.Top
      10                    , //   wsMsg.Width
      10                    , //   wsMsg.Height
      wsMsgCaption          , //   wsMsg.Caption
      Arial16x18_Regular    , //   wsMsg.FontName
      0x632C                , //   still.Font_Color
};
label_t* const wsMsgFig = &wsMsg;

uint8_t const idleCaption[] = "no movement";
clabel_t idleLbl =
{
      86                    , //   wsMsg.Left
      298                   , //   wsMsg.Top
      10                    , //   wsMsg.Width
      10                    , //   wsMsg.Height
      idleCaption           , //   wsMsg.Caption
      Arial11x14_Regular    , //   wsMsg.FontName
      CL_LIGHT              , //   still.Font_Color
};
clabel_t* const idleFig = &idleLbl;

uint8_t const thrBigCaption[] = "threshold too large";
clabel_t thrBigLbl =
{
      77                    , //   wsMsg.Left
      298                   , //   wsMsg.Top
      10                    , //   wsMsg.Width
      10                    , //   wsMsg.Height
      thrBigCaption         , //   wsMsg.Caption
      Arial11x14_Regular    , //   wsMsg.FontName
      CL_LIGHT              , //   still.Font_Color
};
clabel_t* const thrBigFig = &thrBigLbl;

cimage_t welScr =
{
     0                     , //   welScr.Order
     0                     , //   welScr.Left
     0                     , //   welScr.Top
     240                   , //   welScr.Width
     320                   , //   welScr.Height
     welcomeScreen         , //   welScr.Picture_Name
     0                     , //   mikroeLogo.OnPressPtr
};
cimage_t* const welScrFig = &welScr;

cimage_t startBut =
{
  1                     , //   startBut.Order
  42                    , //   startBut.Left
  220                   , //   startBut.Top
  160                   , //   startBut.Width
  40                    , //   startBut.Height
  startImg              , //   startBut.Picture_Name
  ToggleApp             , //   startBut.OnPressPtr
};
cimage_t* const startFig = &startBut;

cimage_t stopBut =
{
  1                     , //   stopBut.Order
  42                    , //   stopBut.Left
  220                   , //   stopBut.Top
  160                   , //   stopBut.Width
  40                    , //   stopBut.Height
  stopImg               , //   stopBut.Picture_Name
  ToggleApp             , //   stopBut.OnPressPtr
};
cimage_t* const stopFig = &stopBut;

cimage_t               calibImg =
 {
   4                     , //   calib1.Order
   0                     , //   calib1.Left
   0                     , //   calib1.Top
   240                   , //   calib1.Width
   320                   , //   calib1.Height
   calibWelScr           , //   calib1.Picture_Name
   0                     , //   calib1.OnPressPtr
 };
 
 cimage_t* const calibWsFig = &calibImg;
 
// time-related
int32_t wtHour, wtMin, wtSec;
int32_t secBuffer;
uint32_t timerTick = 0;

// prevent bounce on a TS button
int32_t bncVal = -1;

// debugging

// temporary variables and variables for comparing sample values
int32_t tmp, currCand, currSam, currRef;
int32_t vpp = 0, dynThr = 0;
int32_t win = 0;

// counters
uint8_t i, j, k;

// flags
bool_t begin = 1,
       initStep = 1,
       currBuffer = 0,
       prevCross = 0, negCross = 0, posCross = 0,
       cond1 = 0, cond2 = 0, cond3 = 0,
       walkingMode = 0,
       stepFlag = 0,
       walkFlag = 0,
       updateTime = 0,
       calcSteps = 0,
       startPedometer = 0;

// threshold parameters
int32_t noiseThr = 0;
int32_t rangeThr = 0;
int32_t currThr = 0;
int32_t tmpThr = 0;
int32_t prethVpp = 0;

// step variables
int32_t step = 0;
int32_t validStep = 0;
int32_t walkStep = 0;
int32_t consecSteps = 0;
int32_t consecValSteps = 0;

uint16_t rClrz[5] = {0xFC00,
                     0xFCE0,
                     0xFDE0,
                     0xFEE0,
                     0xFFE0
};
uint16_t yClrz[5] = {0xFFFF,
                     0xFFF8,
                     0xFFF0,
                     0xFFE8,
                     0xFFE0
};

uint16_t* countsColor = yClrz; // default animation

// variable for reading flags in ADXL345
uint8_t intSources = 0;